@@ -91,7 +91,7 @@ def remove_body(client, api_config, event):
             event["request"]['body'] = ''
             event["request"]['bodyLimitExceeded'] = True
 
-        if len(event["response"]['body']) > MAX_BODY_SIZE:
+        if 'response' in event and len(event["response"].get('body', '')) > MAX_BODY_SIZE:
             event["response"]['body'] = ''
             event["response"]['bodyLimitExceeded'] = True
 
