@@ -121,6 +121,9 @@ class Transport(ThreadManager):
         # add some randomness to timeout to avoid stampedes of several workers that are booted at the same time
         max_flush_time = self._max_flush_time * random.uniform(0.9, 1.1) if self._max_flush_time else None
         while True:
+            if not self.client.config.account_api_configuration or not self.client.config.account_api_configuration.get("uuid"):
+                logger.debug("Wait until central config is returned")
+                time.sleep(1)
             since_last_flush = timeit.default_timer() - self._last_flush
             # take max flush time into account to calculate timeout
             timeout = max(0, max_flush_time - since_last_flush) if max_flush_time else None
@@ -235,15 +238,7 @@ class Transport(ThreadManager):
         self._encode_body_payload(data)
 
         data["metadata"] = {
-            "platform": get_runtime_env(),
-            "agent": {
-                "type": "python",
-                "version": VERSION
-            },
             "configuration": {
-                "global": {
-                    "uuid": self.client.config.account_api_configuration['uuid']
-                },
                 "api": {
                     "uuid": api_config['uuid'] if api_config else ""
                 }
@@ -283,7 +278,20 @@ class Transport(ThreadManager):
             logger.error("dropping flushed data due to transport failure back-off")
         else:
             fileobj = buffer.fileobj  # get a reference to the fileobj before closing the gzip file
-            buffer.write("]}".encode("utf-8"))
+            buffer.write('],"metadata":'.encode('utf-8'))
+            buffer.write(self._json_serializer({
+                "platform": get_runtime_env(),
+                "agent": {
+                    "type": "python",
+                    "version": VERSION
+                },
+                "configuration": {
+                    "global": {
+                        "uuid": self.client.config.account_api_configuration["uuid"] if self.client.config.account_api_configuration else ""
+                    }
+                }
+            }).encode('utf-8'))
+            buffer.write('}'.encode('utf-8'))
             buffer.close()
 
             # StringIO on Python 2 does not have getbuffer, so we need to fall back to getvalue
@@ -321,7 +329,7 @@ class Transport(ThreadManager):
             return
         self._closed = True
         self.queue("close", None)
-        if not self._flushed.wait(timeout=self._max_flush_time * 100):
+        if not self._flushed.wait(timeout=self._max_flush_time):
             raise ValueError("close timed out")
 
     stop_thread = close
@@ -347,7 +355,7 @@ class Transport(ThreadManager):
         Failure handler called by the transport on send failure
         """
         message = str(exception)
-        logger.error("Failed to submit message: %r", message, exc_info=getattr(exception, "print_trace", True))
+        logger.debug("Failed to submit message: %r", message, exc_info=getattr(exception, "print_trace", True))
         self.state.set_fail()
 
 
